%global file_version %%(echo %{version} | cut -d. -f1-2)
%global x11_app_defaults_dir %{_datadir}/X11/app-defaults

%bcond_with texlive
%bcond_with wx
%bcond_with libcerf

Summary: A program for plotting mathematical expressions and data
Name:    gnuplot
Version: 5.4.6
Release: 2%{?dist}
License: gnuplot and MIT
URL:     http://www.gnuplot.info/
Source0: https://udomain.dl.sourceforge.net/project/gnuplot/gnuplot/%{version}/gnuplot-%{version}.tar.gz

Patch3001: gnuplot-4.2.0-fonts.patch
Patch3003: gnuplot-4.6.1-plot-sigsegv.patch
Patch3004: gnuplot-4.6.4-singlethread.patch
Patch3005: gnuplot-5.0.0-lua_checkint.patch
Patch3006: gnuplot-5.4.3-no-lena.patch
Patch3007: gnuplot-5.2.2-doc.patch
Patch3008: gnuplot-config.patch

Requires: %{name}-common = %{version}-%{release}
Requires: dejavu-sans-fonts
Requires(post): /usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives

BuildRequires: cairo-devel emacs gd-devel giflib-devel libotf libpng-devel
BuildRequires: librsvg2 libX11-devel libXt-devel lua-devel m17n-lib pango-devel make
%if %{with texlive}
BuildRequires: tex(latex) tex(subfigure.sty) tex(ecrm1000.tfm) latex2html
BuildRequires: tex(cm-super-t1.enc) tex-tex4ht /usr/bin/texi2dvi
%endif
BuildRequires: zlib-devel libjpeg-turbo-devel texinfo qt5-qtbase-devel qt5-qtsvg-devel qt5-linguist
%if %{with libcerf}
BuildRequires: libcerf-devel
%endif
%if %{with wx} 
BuildRequires: wxGTK-devel
%endif

%description
Gnuplot is a command-line driven, interactive function plotting program especially suited for
scientific data representation.  Gnuplot can be used to plot functions and data points in both two
and three dimensions and in many different formats.

Install gnuplot if you need a graphics package for scientific data representation.

This package provides a Qt based terminal version of gnuplot.

%package common
Summary: The common gnuplot parts

%description common
Gnuplot is a command-line driven, interactive function plotting program especially suited for
scientific data representation.  Gnuplot can be used to plot functions and data points in both two
and three dimensions and in many different formats.

This subpackage contains common parts needed for all versions of gnuplot.

%package minimal
Summary: Minimal version of program for plotting mathematical expressions and data
Requires: %{name}-common = %{version}-%{release}
Requires(post): /usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives

%description minimal
Gnuplot is a command-line driven, interactive function plotting program especially suited for
scientific data representation.  Gnuplot can be used to plot functions and data points in both two
and three dimensions and in many different formats.

Install gnuplot-minimal if you need a minimal version of graphics package for scientific data
representation.

%if %{with wx}
%package wx
Summary: wxGTK interface for gnuplot
Requires: %{name}-common = %{version}-%{release}
Requires(post): /usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives
Provides: gnuplot

%description wx
Gnuplot is a command-line driven, interactive function plotting program especially suited for
scientific data representation.  Gnuplot can be used to plot functions and data points in both two
and three dimensions and in many different formats.

This package provides a wxGTK based terminal version of gnuplot.
%endif

%if %{with texlive}
%package latex
Summary: Configuration for LaTeX typesetting using gnuplot
Requires: %{name} = %{version}-%{release}
Requires: tex(latex), tex(cm-super-t1.enc), tex(ecrm1000.tfm), tex(utf8x.def), tex-preview
BuildArch: noarch

%description latex
The gnuplot-latex package contains LaTeX configuration file related to gnuplot plotting tool.
%endif

%prep
%autosetup -n %{name}-%{version} -p1
sed -i -e 's:"/usr/lib/X11/app-defaults":"%{x11_app_defaults_dir}":' src/gplt_x11.c
chmod 644 src/getcolor.h
chmod 644 demo/html/webify.pl
chmod 644 demo/html/webify_svg.pl
chmod 644 demo/html/webify_canvas.pl

%build
rm -rf demo/plugin/*.so demo/plugin/*.o

%global configure_opts --with-readline=builtin \\\
 --enable-history-file --with-texdir=/usr/share/texlive/texmf-dist/tex/latex/gnuplot

mkdir minimal
cd minimal
ln -s ../configure .
%configure %{configure_opts} \
    --disable-wxwidgets \
    --without-qt \
    %{?with_libcerf:--with-libcerf} \
    %{!?with_libcerf:--without-libcerf} \
    %{nil}

%make_build
cd -

%if %{with wx}
mkdir wx
cd wx
ln -s ../configure .
%configure %{configure_opts} \
    --without-qt \
    %{?with_libcerf:--with-libcerf} \
    %{!?with_libcerf:--without-libcerf} \
    %{nil}
%make_build
cd -
%endif

mkdir qt
cd qt
ln -s ../configure .
%configure %{configure_opts} \
    --disable-wxwidgets \
    --enable-qt \
    %{?with_libcerf:--with-libcerf} \
    %{!?with_libcerf:--without-libcerf} \
    %{nil}
%make_build
cd -

%install
%if %{with wx}
make -C wx install DESTDIR=%{buildroot} INSTALL='install -p'
mv %{buildroot}%{_bindir}/gnuplot %{buildroot}%{_bindir}/gnuplot-wx
%endif

make -C qt install DESTDIR=%{buildroot} INSTALL='install -p'
mv %{buildroot}%{_bindir}/gnuplot %{buildroot}%{_bindir}/gnuplot-qt

install -p -m 755 minimal/src/gnuplot %{buildroot}%{_bindir}/gnuplot-minimal

rm -f %{buildroot}%{_infodir}/dir

mkdir -p %{buildroot}%{x11_app_defaults_dir}
mv %{buildroot}%{_datadir}/gnuplot/%{file_version}/app-defaults/Gnuplot %{buildroot}%{x11_app_defaults_dir}/Gnuplot
rm -rf %{buildroot}%{_libdir}/

ln -s gnuplot.1 %{buildroot}/%{_mandir}/man1/gnuplot-qt.1
%if %{with wx}
ln -s gnuplot.1 %{buildroot}/%{_mandir}/man1/gnuplot-wx.1
%endif

touch %{buildroot}%{_bindir}/gnuplot 

%posttrans
/usr/sbin/alternatives --install %{_bindir}/gnuplot gnuplot %{_bindir}/gnuplot-qt 61

%posttrans minimal
/usr/sbin/alternatives --install %{_bindir}/gnuplot gnuplot %{_bindir}/gnuplot-minimal 40

%if %{with wx}
%posttrans wx
/usr/sbin/alternatives --install %{_bindir}/gnuplot gnuplot %{_bindir}/gnuplot-wx 50
%endif

%preun
if [ $1 = 0 ]; then
    /usr/sbin/alternatives --remove gnuplot %{_bindir}/gnuplot-qt || :
fi

%preun minimal
if [ $1 = 0 ]; then
    /usr/sbin/alternatives --remove gnuplot %{_bindir}/gnuplot-minimal || :
fi

%if %{with wx}
%preun wx
if [ $1 = 0 ]; then
    /usr/sbin/alternatives --remove gnuplot %{_bindir}/gnuplot-wx || :
fi
%endif

%if %{with texlive}
%post latex
[ -e %{_bindir}/texhash ] && %{_bindir}/texhash 2> /dev/null;
%endif

%files
%license Copyright
%ghost %attr(0755,-,-) %{_bindir}/gnuplot
%{_bindir}/gnuplot-qt
%{_libexecdir}/gnuplot/%{file_version}/gnuplot_qt
%{_datadir}/gnuplot/%{file_version}/qt/

%files common
%license Copyright
%doc BUGS FAQ.pdf NEWS README RELEASE_NOTES
%dir %{_datadir}/gnuplot
%dir %{_datadir}/gnuplot/%{file_version}
%dir %{_datadir}/gnuplot/%{file_version}/PostScript
%{_datadir}/gnuplot/%{file_version}/PostScript/*.ps
%{_datadir}/gnuplot/%{file_version}/PostScript/aglfn.txt
%dir %{_datadir}/gnuplot/%{file_version}/js
%{_datadir}/gnuplot/%{file_version}/js/*
%dir %{_datadir}/gnuplot/%{file_version}/lua/
%{_datadir}/gnuplot/%{file_version}/lua/gnuplot-tikz.lua
%{_datadir}/gnuplot/%{file_version}/colors_*
%{_datadir}/gnuplot/%{file_version}/gnuplot.gih
%{_datadir}/gnuplot/%{file_version}/gnuplotrc
%dir %{_libexecdir}/gnuplot
%dir %{_libexecdir}/gnuplot/%{file_version}
%{_libexecdir}/gnuplot/%{file_version}/gnuplot_x11
%{x11_app_defaults_dir}/Gnuplot
%{_mandir}/man1/gnuplot.1*
%{_mandir}/man1/gnuplot-qt.1*

%files minimal
%license Copyright
%ghost %attr(0755,-,-) %{_bindir}/gnuplot
%{_bindir}/gnuplot-minimal

%if %{with wx}
%files wx
%license Copyright
%ghost %attr(0755,-,-) %{_bindir}/gnuplot
%{_bindir}/gnuplot-wx
%{_mandir}/man1/gnuplot-wx.1*
%endif

%if %{with texlive}
%files latex
%license Copyright
%{_texmf_vendor}/tex/latex/gnuplot/
%endif

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.4.6-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 18 2023 Shuo Wang <abushwang@tencent.com> - 5.4.6-1
- initial build
